AccessiblePosition class

Represents an accessible position with information about its ID, label, hint, and position coordinates.

Constructors

AccessiblePosition({required double dx, required double dy, required double width, required double height, String? id, String? label, String? hint})
Creates a new instance of AccessiblePosition with the specified parameters.

Properties

dx → double
final
dy → double
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
hint → String?
final
id → String?
final
label → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the AccessiblePosition instance to a map representation.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited