ConnectHelper class

Connect static helper methods

Constructors

ConnectHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

captureScreen ↔ bool
getter/setter pair
currentLogicalPageName ↔ String
getter/setter pair

Static Methods

canCaptureScreen(String screenName, String jsonString) → bool
Asks the native layer if it can capture the screen with the given screenName. jsonString.
checkForSemantics(WidgetPath? wp) → Map<String, dynamic>
encodeJsonPointerEvent(Object? value) → Object?
errorDetailsHelper(FlutterErrorDetails fed, String type) → Map<String, dynamic>
gestureHelper({Widget? gesture, String? gestureType}) → void
getGestureTarget(WidgetPath wp) → String
pinchGestureHelper({required Widget? gesture, required String onType, Offset? offset, double? scale, Velocity? velocity, int fingers = 0}) → void
pointerEventHelper(String action, PointerEvent pe) → void
updateLogicalPageName(String screenName, String jsonString) → String
Updates the logical page name for a given screen.