WidgetPath class

Tracks Widgets during runtime, for Connect type 10 & type 11

Constructors

WidgetPath()
WidgetPath.create(BuildContext? context, {bool shorten = true, bool hash = false, String exclude = excl})

Properties

context ↔ BuildContext?
getter/setter pair
hash ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ int?
getter/setter pair
parameters ↔ Map<String, dynamic>
getter/setter pair
parent ↔ Element?
getter/setter pair
parentWidgetType ↔ String?
getter/setter pair
path ↔ String
getter/setter pair
pathHash ↔ String?
getter/setter pair
position ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shorten ↔ bool
getter/setter pair
usedInLayout ↔ bool
getter/setter pair

Methods

addInstance(int key) → void
addParameters(Map<String, dynamic> parameters) → void
findExistingPathKeys() → List<int>
isEqual(WidgetPath other) → bool
makeShorter(String str) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
siblingPosition(Element parent, Widget child) → int
toString() → String
A string representation of this object.
inherited
widgetDigest() → String?
widgetPath() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

digest → Hash
no setter
pathCache ↔ Map<Widget, String>
getter/setter pair
removeWhere ↔ Function
getter/setter pair
size → int
no setter
widgetContexts ↔ Map<int, dynamic>
getter/setter pair

Static Methods

clear() → void
clearPathCache() → void
containsKey(int key) → bool
entryList() → List
getPath(int key) → WidgetPath?
removePath(int? key) → void

Constants

excl → const String
reduce → const String
sep → const String