LoggerConfig class

Configuration holder for logging settings

Constructors

LoggerConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

logLevel → ConnectLogLevel
Gets the current log level
no setter

Static Methods

setLogLevel(ConnectLogLevel level) → void
Sets the log level for the SDK