TlHttpLogger class

Constructors

TlHttpLogger()

Properties

hashCode → int
The hash code for this object.
no setterinherited
mDescription ↔ String
getter/setter pair
mInitTime ↔ int
getter/setter pair
mLoadTime ↔ int
getter/setter pair
mResponseSize ↔ int
getter/setter pair
mStatusCode ↔ int
getter/setter pair
mUrl ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

logRequest(RequestData data) → void
logResponse(ResponseData data) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited