ResponseData class

Constructors

ResponseData({required Method method, required String url, required int statusCode, Map<String, String>? headers, required String body, List<int>? bodyBytes, int? contentLength, bool? isRedirect, bool? persistentConnection})
ResponseData.fromHttpResponse(Response response)
factory

Properties

body ↔ String
getter/setter pair
bodyBytes ↔ List<int>?
getter/setter pair
contentLength ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>?
getter/setter pair
isRedirect ↔ bool?
getter/setter pair
method ↔ Method
getter/setter pair
persistentConnection ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode ↔ int
getter/setter pair
url ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited